// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package environment

import (
	"os"
	"path"
	"path/filepath"
	"regexp"
	"strings"
)

const defaultMarkdownTemplate = `
---
date: {{ .CreatedFormat }}
...
{{ .Documents }}
`

func ReadTemplate(argPath string) string {

	if argPath == "" {
		return defaultMarkdownTemplate
	}

	current, err := os.Getwd()
	if err != nil {
		ExitWithError(2, "The current directory cannot be read")
	}

	p := argPath

	if !filepath.IsAbs(p) {
		p = path.Clean(current + "/" + p)
	}

	template, err := os.ReadFile(p)
	if err != nil {
		ExitWithError(2, "The template file %s cannot be read.", p)
	}

	return convertTemplateImages(string(template), path.Dir(p))
}

func convertTemplateImages(content string, absolute string) string {
	content = convertTemplateLogo(content, absolute)
	content = convertTemplateLatexLogo(content, absolute)

	return content

}

func convertTemplateLogo(content string, absolute string) string {
	todoRegEx := regexp.MustCompile(`(?m)^(?P<match>logo:\s*"?(?P<path>[^"\n]*)"?\s*)$`)

	matches := todoRegEx.FindAllStringSubmatch(content, -1)
	if matches == nil {
		return content
	}

	for _, match := range matches {
		result := make(map[string]string)
		for i, name := range todoRegEx.SubexpNames() {
			if i != 0 && name != "" {
				result[name] = match[i]
			}
		}

		if filepath.IsAbs(result["path"]) {
			continue
		}

		path := path.Clean(absolute + "/" + result["path"])
		content = strings.Replace(content, result["match"], "logo: \""+path+"\"", -1)

	}

	return content
}

func convertTemplateLatexLogo(content string, absolute string) string {
	todoRegEx := regexp.MustCompile(`(?m)(?P<match>\\includegraphics[^{]*\{(?P<path>[^}]*)\})`)

	matches := todoRegEx.FindAllStringSubmatch(content, -1)
	if matches == nil {
		return content
	}

	for _, match := range matches {
		result := make(map[string]string)
		for i, name := range todoRegEx.SubexpNames() {
			if i != 0 && name != "" {
				result[name] = match[i]
			}
		}

		if filepath.IsAbs(result["path"]) {
			continue
		}

		path := path.Clean(absolute + "/" + result["path"])
		a := strings.Replace(result["match"], result["path"], path, -1)

		content = strings.Replace(content, result["match"], a, -1)

	}

	return content
}
