// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package translations

//go:generate gotext -srclang=en update -out=catalog.go -lang=en,de gitlab.schukai.com/oss/utilities/documentation-manager

import (
	"golang.org/x/text/language"
	"golang.org/x/text/message"
	"os"
	"strings"
)

var T *L10n

func init() {
	T = &L10n{}
	T.init()
}

type L10n struct {
	tag     language.Tag
	printer *message.Printer
}

func (t *L10n) Printf(format string, args ...interface{}) {
	t.GetPrinter().Printf(format, args...)
}

func (t *L10n) Sprintf(format string, args ...interface{}) string {
	return t.GetPrinter().Sprintf(format, args...)
}

func (t *L10n) GetPrinter() *message.Printer {
	if t.printer == nil {
		t.printer = message.NewPrinter(t.tag)
	}
	return t.printer
}

func (t *L10n) init() {

	defer func() {
		if r := recover(); r != nil {
			t.tag = language.English
		}
	}()

	lang := os.Getenv("LANGUAGE")
	if lang == "" {
		lang = os.Getenv("LANG")
	}

	parts := strings.Split(lang, ".")
	if len(parts) > 0 {
		lang = parts[0]
	}

	t.tag = language.MustParse(lang)

}
